**********************
Gstreamer installation
**********************

**TODO** Document Gstreamer installation on Linux, OS X and Windows.

To install Gstreamer on OS X::

    sudo port install py26-gst-python py26-gobject \
        gstreamer-plugins-good gstreamer-plugins-ugly
